@@ -205,10 +205,19 @@ define(["base/js/namespace"], function (Jupyter) {
                         Jupyter.notebook.events.one(
                             "kernel_ready.Kernel",
                             () => {
+                                console.log("We actually reloaded!");
                                 create_and_register_comm();
                             }
                         );
                     }
+                    Jupyter.notebook.events.on(
+                        "kernel_ready.Kernel",
+                        () => {
+                            console.log("Registering notebook after kernel restart...");
+                            Jupyter.notebook.kernel.execute("import jupyter_ascending.extension; jupyter_ascending.extension.set_everything_up()");
+                        }
+                    );
+
                     console.log("... success!");
 
                     console.log("===================================");
